# $Id: builder.py,v 1.2 2001/07/30 06:49:06 erik Exp $
# $Source: /cvs/make_product/builder.py,v $
__version__='$Revision: 1.2 $'[11:-2]

"""The builder module provides nice builder/factory-functions to set
up instances of whatever turns you on.  Make sure you use these
methods instead of accessing the classes directly; 'cus that's a
no-no."""

import product
import klass
import method
import property

def zope_product_builder(**kw):
    """Helper-method for building a zope_product instance"""
    id = kw['id']
    try: license = kw['license']
    except KeyError: license = ''
    try: docstring = kw['docstring']
    except KeyError: docstring = '"""doc string"""'
    try: default_indent = kw['default_indent']
    except KeyError: default_indent = '    '
    try: directory = kw['directory']
    except KeyError: directory = ''
    try: author = kw['author']
    except KeyError: author = ''
    try: author_email = kw['author_email']
    except KeyError: author_email = ''
    try: authored_year = kw['authored_year']
    except KeyError: authored_year = ''
    try: form_creator = kw['form_creator']
    except KeyError: form_creator = 'self'
    return product.zope_product(
        id=id, license=license, docstring=docstring,
        default_indent=default_indent, directory=directory,
        author=author, author_email=author_email,
        authored_year=authored_year, form_creator=form_creator)

def klass_product_builder(**kw):
    """Helper-method for building a klass_product instance"""
    return product.klass_product(id=kw['id'])

def basic_product_builder(**kw):
    """Helper-method for building a basic_product instance"""
    return product.klass_product(id=kw['id'])

def klass_builder(**kw):
    """Helper-method for building a klass instance"""
    id = kw['id']
    try: default_indent = kw['default_indent']
    except KeyError: default_indent = '    '
    try: license = kw['license']
    except KeyError: license = ''
    try: docstring = kw['docstring']
    except KeyError: docstring = '"""doc string"""'
    try: meta_type = kw['meta_type']
    except KeyError: meta_type = ''
    try: icon_path = kw['icon_path']
    except KeyError: icon_path = ''
    try: misc_headers = kw['misc_headers']
    except KeyError: misc_headers = ''
    try: module_docstring = kw['module_docstring']
    except KeyError: module_docstring = '"""doc string"""'
    try: author = kw['author']
    except KeyError: author = ''
    try: author_email = kw['author_email']
    except KeyError: author_email = ''
    try: authored_year = kw['authored_year']
    except KeyError: authored_year = ''
    try: type = kw['type']
    except KeyError: type = 'SimpleItem'
    return klass.klass(
        id=id, default_indent=default_indent, license=license,
        docstring=docstring, meta_type=meta_type, icon_path=icon_path,
        misc_headers=misc_headers, module_docstring=module_docstring,
        author=author, author_email=author_email,
        authored_year=authored_year, type=type)

def property_klass_builder(**kw):
    """Helper-method for building a property_klass instance"""
    id = kw['id']
    try: default_indent = kw['default_indent']
    except KeyError: default_indent = '    '
    try: license = kw['license']
    except KeyError: license = ''
    try: docstring = kw['docstring']
    except KeyError: docstring = '"""doc string"""'
    try: meta_type = kw['meta_type']
    except KeyError: meta_type = ''
    try: icon_path = kw['icon_path']
    except KeyError: icon_path = ''
    try: misc_headers = kw['misc_headers']
    except KeyError: misc_headers = ''
    try: module_docstring = kw['module_docstring']
    except KeyError: module_docstring = '"""doc string"""'
    try: author = kw['author']
    except KeyError: author = ''
    try: author_email = kw['author_email']
    except KeyError: author_email = ''
    try: authored_year = kw['authored_year']
    except KeyError: authored_year = ''
    try: type = kw['type']
    except KeyError: type = 'SimpleItem'
    return klass.property_klass(
        id=id, default_indent=default_indent, license=license,
        docstring=docstring, meta_type=meta_type, icon_path=icon_path,
        misc_headers=misc_headers, module_docstring=module_docstring,
        author=author, author_email=author_email,
        authored_year=authored_year, type=type)

def klass_rendrer_builder(**kw):
    """Helper-method for building a property_klass instance"""
    id = kw['id']
    try: default_indent = kw['default_indent']
    except KeyError: default_indent = '    '
    try: license = kw['license']
    except KeyError: license = ''
    try: docstring = kw['docstring']
    except KeyError: docstring = '"""doc string"""'
    try: meta_type = kw['meta_type']
    except KeyError: meta_type = ''
    try: icon_path = kw['icon_path']
    except KeyError: icon_path = ''
    try: misc_headers = kw['misc_headers']
    except KeyError: misc_headers = ''
    try: module_docstring = kw['module_docstring']
    except KeyError: module_docstring = '"""doc string"""'
    try: author = kw['author']
    except KeyError: author = ''
    try: author_email = kw['author_email']
    except KeyError: author_email = ''
    try: authored_year = kw['authored_year']
    except KeyError: authored_year = ''
    try: type = kw['type']
    except KeyError: type = 'SimpleItem'
    return klass.klass_rendrer(
        id=id, default_indent=default_indent, license=license,
        docstring=docstring, meta_type=meta_type, icon_path=icon_path,
        misc_headers=misc_headers, module_docstring=module_docstring,
        author=author, author_email=author_email,
        authored_year=authored_year, type=type)

def property_klass_rendrer_builder(**kw):
    """Helper-method for building a property_klass instance"""
    id = kw['id']
    try: default_indent = kw['default_indent']
    except KeyError: default_indent = '    '
    try: license = kw['license']
    except KeyError: license = ''
    try: docstring = kw['docstring']
    except KeyError: docstring = '"""doc string"""'
    try: meta_type = kw['meta_type']
    except KeyError: meta_type = ''
    try: icon_path = kw['icon_path']
    except KeyError: icon_path = ''
    try: misc_headers = kw['misc_headers']
    except KeyError: misc_headers = ''
    try: module_docstring = kw['module_docstring']
    except KeyError: module_docstring = '"""doc string"""'
    try: author = kw['author']
    except KeyError: author = ''
    try: author_email = kw['author_email']
    except KeyError: author_email = ''
    try: authored_year = kw['authored_year']
    except KeyError: authored_year = ''
    try: type = kw['type']
    except KeyError: type = 'SimpleItem'
    return klass.property_klass_rendrer(
        id=id, default_indent=default_indent, license=license,
        docstring=docstring, meta_type=meta_type, icon_path=icon_path,
        misc_headers=misc_headers, module_docstring=module_docstring,
        author=author, author_email=author_email,
        authored_year=authored_year, type=type)

def method_klass_rendrer_builder(**kw):
    """Helper-method for building a property_klass instance"""
    id = kw['id']
    try: default_indent = kw['default_indent']
    except KeyError: default_indent = '    '
    try: license = kw['license']
    except KeyError: license = ''
    try: docstring = kw['docstring']
    except KeyError: docstring = '"""doc string"""'
    try: meta_type = kw['meta_type']
    except KeyError: meta_type = ''
    try: icon_path = kw['icon_path']
    except KeyError: icon_path = ''
    try: misc_headers = kw['misc_headers']
    except KeyError: misc_headers = ''
    try: module_docstring = kw['module_docstring']
    except KeyError: module_docstring = '"""doc string"""'
    try: author = kw['author']
    except KeyError: author = ''
    try: author_email = kw['author_email']
    except KeyError: author_email = ''
    try: authored_year = kw['authored_year']
    except KeyError: authored_year = ''
    try: type = kw['type']
    except KeyError: type = 'SimpleItem'
    return klass.method_klass_rendrer(
        id=id, default_indent=default_indent, license=license,
        docstring=docstring, meta_type=meta_type, icon_path=icon_path,
        misc_headers=misc_headers, module_docstring=module_docstring,
        author=author, author_email=author_email,
        authored_year=authored_year, type=type)

def method_klass_builder(**kw):
    """Helper-method for building a property_klass instance"""
    id = kw['id']
    try: default_indent = kw['default_indent']
    except KeyError: default_indent = '    '
    try: license = kw['license']
    except KeyError: license = ''
    try: docstring = kw['docstring']
    except KeyError: docstring = '"""doc string"""'
    try: meta_type = kw['meta_type']
    except KeyError: meta_type = ''
    try: icon_path = kw['icon_path']
    except KeyError: icon_path = ''
    try: misc_headers = kw['misc_headers']
    except KeyError: misc_headers = ''
    try: module_docstring = kw['module_docstring']
    except KeyError: module_docstring = '"""doc string"""'
    try: author = kw['author']
    except KeyError: author = ''
    try: author_email = kw['author_email']
    except KeyError: author_email = ''
    try: authored_year = kw['authored_year']
    except KeyError: authored_year = ''
    try: type = kw['type']
    except KeyError: type = 'SimpleItem'
    return klass.method_klass(
        id=id, default_indent=default_indent, license=license,
        docstring=docstring, meta_type=meta_type, icon_path=icon_path,
        misc_headers=misc_headers, module_docstring=module_docstring,
        author=author, author_email=author_email,
        authored_year=authored_year, type=type)

def basic_klass_builder(**kw):
    """Helper-method for building a basic_klass instance"""
    return klass.basic_klass(id=kw['id'])

def method_builder(**kw):
    """Helper-method for building a method instance"""
    id = kw['id']
    try:
        if 'self' not in kw['arguments']:
            arguments = ['self'] + kw['arguments']
    except KeyError:
        arguments = ['self']
    try: docstring = kw['docstring']
    except KeyError: docstring = '"""doc string"""'
    try: default_indent = kw['default_indent']
    except KeyError: default_indent = '    '
    try: body = kw['body']
    except KeyError: body = default_indent + 'pass'
    try:
        security = kw['security']
        permission = kw['permission']
    except KeyError:
        security = 'public'
        permission = ''
    return method.method(
        id=id, arguments=arguments, docstring=docstring,
        default_indent=default_indent, body=body, security=security,
        permission=permission)

def property_builder(**kw):
    """Helper-method for building a property instance"""
    id = kw['id']
    try: type = kw['type']
    except KeyError: type = 'string'
    try: default = kw['default']
    except KeyError: default = "''"
    try: mode = kw['mode']
    except KeyError: mode = 'w'
    return property.property(
        id=id, type=type, default=default, mode=mode)    

