# $Id: method.py,v 1.3 2001/07/30 06:49:06 erik Exp $
# $Source: /cvs/make_product/method.py,v $
__version__='$Revision: 1.3 $'[11:-2]

"""A collection of classes for creating and maintaining methods within
klass instances.  As you can see, the method class does not know how
to render itself, it needs to subclass the method_rendrer to be able to
do that."""

import types
import string

class basic_method:
    """A basic method"""

    def __init__(self, **kw):
        """Initialize an instance of the class"""
        self.id = kw['id']
        try:
            if 'self' not in kw['arguments']:
                arguments = ['self'] + kw['arguments']
            else:
                arguments = ['self']
            self.arguments = arguments
        except KeyError:
            self.arguments = ['self']
        try: self.docstring = kw['docstring']
        except KeyError: self.docstring = '"""doc string"""'
        try: self.default_indent = kw['default_indent']
        except KeyError: self.default_indent = '    '
        try: self.body = kw['body']
        except KeyError: self.body = self.default_indent + 'pass'
        try:
            self.security = kw['security']
            self.permission = kw['permission']
        except KeyError:
            self.security = 'public'
            self.permission = ''

    def get_arguments(self):
        """Return the arguments for the method"""
        return self.arguments

class method_rendrer(basic_method):
    """Provides methods for rendering a basic_method instance"""

    def render_security_declaration(self, indent):
        """Return the security declaration"""
        if self.security == 'public':
            return indent + "security.declarePublic('%s')\n" % self.id
        elif self.security == 'private':
            return indent + "security.declarePrivate('%s', '%s')\n" % \
                   (self.permission, self.id)

    def render_arguments(self):
        """Return the arguments-string"""
        arguments = ""
        for argument in self.get_arguments():
            if arguments <> "":
                arguments = arguments + ", "
            if type(argument) == types.ListType:
                arguments = arguments + argument[0] + "=" +\
                            str(argument[1])
            else:
                arguments = arguments + argument
        return arguments

    def render_body(self, indent=''):
        """Return the body of the method"""
        if self.body:
            text = ""
            for line in string.split(self.body, '\n'):
                text = text + indent + line + "\n"
            return text
        else:
            return indent + self.default_indent + "pass\n"

    def render_self(self, indent=''):
        """Render the method instance in text.  This will be
        used when the product class will write itself out to
        the filesystem."""
        text = self.render_security_declaration(indent)
        text = text + indent + "def " + self.id + "(" + \
               self.render_arguments() + "):\n"
        text = text + indent + self.default_indent + self.docstring + "\n"
        text = text + self.render_body(indent)
        return text

class method(method_rendrer):
    """doc string"""
    pass




